# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.26
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from nuon.models.app_app_sandbox_config_artifacts import AppAppSandboxConfigArtifacts

class TestAppAppSandboxConfigArtifacts(unittest.TestCase):
    """AppAppSandboxConfigArtifacts unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AppAppSandboxConfigArtifacts:
        """Test AppAppSandboxConfigArtifacts
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AppAppSandboxConfigArtifacts`
        """
        model = AppAppSandboxConfigArtifacts()
        if include_optional:
            return AppAppSandboxConfigArtifacts(
                cloudformation_stack_template = '',
                deprovision_policy = '',
                provision_policy = '',
                trust_policy = ''
            )
        else:
            return AppAppSandboxConfigArtifacts(
        )
        """

    def testAppAppSandboxConfigArtifacts(self):
        """Test AppAppSandboxConfigArtifacts"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.15
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from nuon.models.app_external_image_component_config import AppExternalImageComponentConfig

class TestAppExternalImageComponentConfig(unittest.TestCase):
    """AppExternalImageComponentConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AppExternalImageComponentConfig:
        """Test AppExternalImageComponentConfig
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AppExternalImageComponentConfig`
        """
        model = AppExternalImageComponentConfig()
        if include_optional:
            return AppExternalImageComponentConfig(
                aws_ecr_image_config = nuon.models.app/awsecr_image_config.app.AWSECRImageConfig(
                    aws_region = '', 
                    component_config_id = '', 
                    component_config_type = '', 
                    created_at = '', 
                    created_by_id = '', 
                    iam_role_arn = '', 
                    id = '', 
                    updated_at = '', ),
                component_config_connection_id = '',
                created_at = '',
                created_by_id = '',
                id = '',
                image_url = '',
                tag = '',
                updated_at = ''
            )
        else:
            return AppExternalImageComponentConfig(
        )
        """

    def testAppExternalImageComponentConfig(self):
        """Test AppExternalImageComponentConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.42
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json




from pydantic import BaseModel, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class AppAppInstallerMetadata(BaseModel):
    """
    AppAppInstallerMetadata
    """ # noqa: E501
    app_installer_id: Optional[StrictStr] = None
    community_url: Optional[StrictStr] = None
    created_at: Optional[StrictStr] = None
    created_by_id: Optional[StrictStr] = None
    demo_url: Optional[StrictStr] = None
    description: Optional[StrictStr] = None
    documentation_url: Optional[StrictStr] = None
    github_url: Optional[StrictStr] = None
    homepage_url: Optional[StrictStr] = None
    id: Optional[StrictStr] = None
    logo_url: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    post_install_markdown: Optional[StrictStr] = None
    updated_at: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["app_installer_id", "community_url", "created_at", "created_by_id", "demo_url", "description", "documentation_url", "github_url", "homepage_url", "id", "logo_url", "name", "post_install_markdown", "updated_at"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of AppAppInstallerMetadata from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of AppAppInstallerMetadata from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "app_installer_id": obj.get("app_installer_id"),
            "community_url": obj.get("community_url"),
            "created_at": obj.get("created_at"),
            "created_by_id": obj.get("created_by_id"),
            "demo_url": obj.get("demo_url"),
            "description": obj.get("description"),
            "documentation_url": obj.get("documentation_url"),
            "github_url": obj.get("github_url"),
            "homepage_url": obj.get("homepage_url"),
            "id": obj.get("id"),
            "logo_url": obj.get("logo_url"),
            "name": obj.get("name"),
            "post_install_markdown": obj.get("post_install_markdown"),
            "updated_at": obj.get("updated_at")
        })
        return _obj





# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.42
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json




from pydantic import BaseModel, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from nuon.models.app_connected_github_vcs_config import AppConnectedGithubVCSConfig
from nuon.models.app_public_git_vcs_config import AppPublicGitVCSConfig
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class AppTerraformModuleComponentConfig(BaseModel):
    """
    AppTerraformModuleComponentConfig
    """ # noqa: E501
    component_config_connection_id: Optional[StrictStr] = Field(default=None, description="parent reference")
    connected_github_vcs_config: Optional[AppConnectedGithubVCSConfig] = None
    created_at: Optional[StrictStr] = None
    created_by_id: Optional[StrictStr] = None
    env_vars: Optional[Dict[str, StrictStr]] = None
    id: Optional[StrictStr] = None
    public_git_vcs_config: Optional[AppPublicGitVCSConfig] = None
    updated_at: Optional[StrictStr] = None
    variables: Optional[Dict[str, StrictStr]] = None
    version: Optional[StrictStr] = Field(default=None, description="terraform configuration values")
    __properties: ClassVar[List[str]] = ["component_config_connection_id", "connected_github_vcs_config", "created_at", "created_by_id", "env_vars", "id", "public_git_vcs_config", "updated_at", "variables", "version"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of AppTerraformModuleComponentConfig from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of connected_github_vcs_config
        if self.connected_github_vcs_config:
            _dict['connected_github_vcs_config'] = self.connected_github_vcs_config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of public_git_vcs_config
        if self.public_git_vcs_config:
            _dict['public_git_vcs_config'] = self.public_git_vcs_config.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of AppTerraformModuleComponentConfig from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "component_config_connection_id": obj.get("component_config_connection_id"),
            "connected_github_vcs_config": AppConnectedGithubVCSConfig.from_dict(obj.get("connected_github_vcs_config")) if obj.get("connected_github_vcs_config") is not None else None,
            "created_at": obj.get("created_at"),
            "created_by_id": obj.get("created_by_id"),
            "env_vars": obj.get("env_vars"),
            "id": obj.get("id"),
            "public_git_vcs_config": AppPublicGitVCSConfig.from_dict(obj.get("public_git_vcs_config")) if obj.get("public_git_vcs_config") is not None else None,
            "updated_at": obj.get("updated_at"),
            "variables": obj.get("variables"),
            "version": obj.get("version")
        })
        return _obj





# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.15
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from nuon.models.service_create_terraform_module_component_config_request import ServiceCreateTerraformModuleComponentConfigRequest

class TestServiceCreateTerraformModuleComponentConfigRequest(unittest.TestCase):
    """ServiceCreateTerraformModuleComponentConfigRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServiceCreateTerraformModuleComponentConfigRequest:
        """Test ServiceCreateTerraformModuleComponentConfigRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServiceCreateTerraformModuleComponentConfigRequest`
        """
        model = ServiceCreateTerraformModuleComponentConfigRequest()
        if include_optional:
            return ServiceCreateTerraformModuleComponentConfigRequest(
                connected_github_vcs_config = nuon.models.service/connected_github_vcs_config_request.service.ConnectedGithubVCSConfigRequest(
                    branch = '', 
                    directory = '', 
                    git_ref = '', 
                    repo = '', ),
                env_vars = {
                    'key' : ''
                    },
                public_git_vcs_config = nuon.models.service/public_git_vcs_config_request.service.PublicGitVCSConfigRequest(
                    branch = '', 
                    directory = '', 
                    repo = '', ),
                variables = {
                    'key' : ''
                    },
                version = ''
            )
        else:
            return ServiceCreateTerraformModuleComponentConfigRequest(
                env_vars = {
                    'key' : ''
                    },
                variables = {
                    'key' : ''
                    },
        )
        """

    def testServiceCreateTerraformModuleComponentConfigRequest(self):
        """Test ServiceCreateTerraformModuleComponentConfigRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
